#!/bin/bash

usage()
{
cat << EOF
	Usage: `basename $0` <OPTIONS>

	OPTIONS:
		get-distro
		get-distro-major
EOF
}

get_distro()
{
	case "$(rpm -qf /etc/issue)" in
	openSUSE-release-12.1*)
	distro=openSUSE12sp1
	;;
	openSUSE-release-11.1*)
	distro=openSUSE11sp1
	;;
	sles-release-11.2*)
	distro=sles11sp2
	;;
	sles-release-11.1*)
	distro=sles11sp1
	;;
	sles-release-11.2-1.206)
	distro=sles11sp2rc3
	;;
	sles-release-10-15.45.8)
	distro=sles10.3
	;;
	sles-release-10-15.57.1)
	distro=sles10sp4
	;;
	sles-release-11-72.13)
	distro=sles11
	;;
	redhat-release*-6.0*|centos-release-6-0*|sl-release-6.0|enterprise-release*-6.0*)
	distro=rhel6.0
	;;
	redhat-release*-6.1*|centos-release-6-1*|sl-release-6.1|enterprise-release*-6.1*)
	distro=rhel6.1
	;;
	redhat-release*-6.2*|centos-release-6-2*|sl-release-6.2|enterprise-release*-6.2*)
	distro=rhel6.2
	;;
	redhat-release*-6.3*|centos-release-6-3*|sl-release-6.3|enterprise-release*-6.3*)
	distro=rhel6.3
	;;
	redhat-release*-6.4*|centos-release-6-4*|sl-release-6.4|enterprise-release*-6.4*)
	distro=rhel6.4
	;;
	redhat-release*-5.9*|centos-release-5-9*)
	distro=rhel5.9
	;;
	redhat-release*-5.8*|centos-release-5-8*)
	distro=rhel5.8
	;;
	redhat-release*-5.7*|centos-release-5-7*)
	distro=rhel5.7
	;;
	redhat-release*-5.6*|centos-release-5-6*)
	distro=rhel5.6
	;;
	redhat-release*-5.5*|centos-release-5-6*)
	distro=rhel5.5
	;;
	*)
	distro="unsupported"
	;;
	esac

	echo $distro
}

get_distro_major()
{
	case "$1" in
	sles11*|openSUSE12*)
	distro_major=sles11
	;;
	sles10*|openSUSE11*)
	distro_major=sles10
	;;
	rhel6*)
	distro_major=rhel6
	;;
	rhel5*)
	distro_major=rhel5
	;;
	*)
	distro_major="unsupported"
	;;
	esac

	echo $distro_major
}


main()
{
	case "$1" in
	get-distro)
	get_distro
	exit 0
	;;
	get-distro-major)
	get_distro_major `get_distro`
	exit 0
	;;
	-h | --help)
	usage
	exit 0
	;;
	*)
	usage
	exit 1
	;;
	esac
}

main $@
